@@ -1,7 +1,7 @@
 /*
   This file is part of KAddressBook Kontact Plugin.
 
-  SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2009-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,7 +33,7 @@ class KAddressBookPlugin : public KontactInterface::Plugin
     Q_OBJECT
 
 public:
-    KAddressBookPlugin(KontactInterface::Core *core, const QVariantList &);
+    explicit KAddressBookPlugin(KontactInterface::Core *core, const QVariantList &);
     ~KAddressBookPlugin() override;
 
     bool isRunningStandalone() const override;
