@@ -1,6 +1,6 @@
 /*
   SPDX-FileCopyrightText: 2009 Tobias Koenig <tokoe@kde.org>
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -64,7 +64,7 @@ public:
     Q_REQUIRED_RESULT Akonadi::Item::List selectedItems() const;
 
 private:
-    ContactSelectionWidget *mSelectionWidget = nullptr;
+    ContactSelectionWidget *const mSelectionWidget;
     ExportSelectionWidget *mVCardExport = nullptr;
 };
 }
