@@ -27,8 +27,8 @@
 #include "importexport/plugininterface.h"
 #include "importexport/pluginmanager.h"
 
-#include <Akonadi/Contact/GrantleeContactFormatter>
-#include <Akonadi/Contact/GrantleeContactGroupFormatter>
+#include <Akonadi/GrantleeContactFormatter>
+#include <Akonadi/GrantleeContactGroupFormatter>
 #include <GrantleeTheme/GrantleeThemeManager>
 
 #include "uistatesaver.h"
@@ -45,19 +45,19 @@
 #include <Akonadi/EntityMimeTypeFilterModel>
 #include <Akonadi/EntityTreeView>
 #include <Akonadi/MimeTypeChecker>
-#include <AkonadiSearch/Debug/akonadisearchdebugdialog.h>
+#include <Debug/akonadisearchdebugdialog.h>
 #include <KContacts/Addressee>
 #include <PimCommon/PimUtil>
 #include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
 #include <QPointer>
 
-#include <Akonadi/Contact/ContactDefaultActions>
-#include <Akonadi/Contact/ContactGroupEditorDialog>
-#include <Akonadi/Contact/ContactGroupViewer>
-#include <Akonadi/Contact/ContactViewer>
-#include <Akonadi/Contact/ContactsFilterProxyModel>
-#include <Akonadi/Contact/ContactsTreeModel>
-#include <Akonadi/Contact/StandardContactActionManager>
+#include <Akonadi/ContactDefaultActions>
+#include <Akonadi/ContactGroupEditorDialog>
+#include <Akonadi/ContactGroupViewer>
+#include <Akonadi/ContactViewer>
+#include <Akonadi/ContactsFilterProxyModel>
+#include <Akonadi/ContactsTreeModel>
+#include <Akonadi/StandardContactActionManager>
 
 #include "kaddressbook_debug.h"
 #include <KActionCollection>
@@ -76,7 +76,7 @@
 #include <QTextBrowser>
 
 #include <Akonadi/ItemModifyJob>
-#include <KPimPrintPreviewDialog>
+#include <PimCommon/KPimPrintPreviewDialog>
 #include <QActionGroup>
 #include <QDBusConnection>
 #include <QHBoxLayout>
@@ -111,17 +111,17 @@ public:
     {
     }
 
-    QVariant data(const QModelIndex &index, int role) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override
     {
         if (!index.isValid()) {
-            return QVariant();
+            return {};
         }
 
         if (role == Qt::CheckStateRole) {
             // Don't show the checkbox if the collection can't contain incidences
             const auto collection = index.data(Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
             if (collection.isValid() && isStructuralCollection(collection)) {
-                return QVariant();
+                return {};
             }
         }
         return KCheckableProxyModel::data(index, role);
@@ -131,11 +131,7 @@ public:
 
 MainWidget::MainWidget(KXMLGUIClient *guiClient, QWidget *parent)
     : QWidget(parent)
-    , mAllContactsModel(nullptr)
     , mXmlGuiClient(guiClient)
-    , mGrantleeThemeManager(nullptr)
-    , mQuickSearchAction(nullptr)
-    , mServerSideSubscription(nullptr)
 {
     (void)new KaddressbookAdaptor(this);
     QDBusConnection::sessionBus().registerObject(QStringLiteral("/KAddressBook"), this);
@@ -831,7 +827,7 @@ Akonadi::Collection MainWidget::currentAddressBook() const
         return collection;
     }
 
-    return Akonadi::Collection();
+    return {};
 }
 
 QAbstractItemModel *MainWidget::allContactsModel()
