@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef RINGBINDERSTYLE_H
-#define RINGBINDERSTYLE_H
+#pragma once
 
 #include "printstyle.h"
 
@@ -38,4 +37,3 @@ public:
 };
 }
 
-#endif
